@@ -13,19 +13,19 @@ from ForMark.singleton import Singleton
 # log_file_path = os.path.join(BASE_DIR, 'log/bb.log')
 
 class ForLog(Singleton):
-    def __init__(self, log_file_path):
+    def __init__(self, log_file_path="/logs/mark"):
         print(log_file_path)
-        logger.add(log_file_path, format="{time:YYYY-MM-DD at HH:mm:ss} | {level} | {message}", filter="", level="INFO")
+        logger.add(
+            log_file_path, format="{time:YYYY-MM-DD at HH:mm:ss} | {level} | {message}", filter="", level="INFO")
 
     @classmethod
-    def logger_info(cls,*msg):
+    def logger_info(cls, *msg):
         logger.info(msg)
 
     @classmethod
-    def show(cls,*msg):
+    def show(cls, *msg):
         logger.info(msg)
 
     @classmethod
-    def logger_error(cls,*msg):
+    def logger_error(cls, *msg):
         logger.error(msg)
-
